#
# spec file for package python-slixmpp
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-slixmpp
Version:        1.8.6
Release:        1.2
Summary:        Python XMPP (Jabber) Library that Implements Everything as a Plugin
License:        MIT
URL:            https://slixmpp.readthedocs.io/
Source:         https://codeberg.org/poezio/slixmpp/archive/slix-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module aiodns}
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module xml}
BuildRequires:  fdupes
BuildRequires:  gnupg
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(libidn)
Requires:       python-aiodns
Requires:       python-aiohttp
Requires:       python-cryptography
Requires:       python-pyasn1
Requires:       python-pyasn1-modules
%python_subpackages

%description
Slixmpp is an XMPP library for Python. Based on SleekXMPP, it uses
asyncio instead of threads. XEP (XMPP Extended Protocol) coverage is
realized as plugins.

%prep
%autosetup -p1 -n slixmpp
sed -i '/\#\!\/usr\/bin\/env\ python3/d' slixmpp/plugins/xep_0454/__init__.py

%build
export CFLAGS="%{optflags}"
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}/

%check
%python_exec run_tests.py

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitearch}/slixmpp
%{python_sitearch}/slixmpp-%{version}.dist-info

%changelog
* Tue Jan  7 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.8.6
  * Moving away from self-hosted gitlab (mathieui)
  * Fix connection to Snikket instances (pep., mathieui)
  * Performance fix for XEP-0115 queries
  * New documentation listing projects using slixmpp (genghis)
  * Bugfix and improvements (nicoco, mostly)
- Remove shebang from slixmpp/plugins/xep_0454/__init__.py
* Tue Feb 27 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.8.5:
  * Fix connection to Snikket instances (pep., mathieui)
  * Performance fix for XEP-0115 queries
  * New documentation listing projects using slixmpp (genghis)
  * Bugfix and improvements (nicoco, mostly)
- Switch to autosetup and pyproject macros.
- Drop patch slixmpp-fix-legacyauth.patch, no longer required.
- Update Source URL.
* Tue Dec  6 2022 Michael Vetter <mvetter@suse.com>
- bsc#1205433 Update to 1.8.3:
  * Fix CVE-2022-45197: missing certificate hostname validation
* Sat Oct 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.8.2
  - Improve error handling for certificate errors
  - Add an XEP-0454 implementation (OMEMO Media sharing)
  - Fix support for RFC 3920 sessions
- Update to version 1.8.1
  * Fix a mypy issue, a test issue, and do not enable defusedxml unless
    explicitly asked.
- Update to version 1.8.0
  * The most important part of this release is that it fixes compatibility with
  python 3.10, but there are also plenty of changes and bugfixes!
  Many XEPs have been modified to accomodate an internal change, and as a
  result their public APIs have been modified. Slixmpp has an "internal API"
  for plugins, inherited from SleekXMPP which allows users of the library to
  substitute internal functions with their own, in order to e.g. provide a
  different storage backend (many default to in-memory), etc. This API has
  always been synchronous, which is not ideal in an asyncio library, and puts
  huge limits on what is possible to do.
  This change makes it possible to use async functions with the internal API,
  and as a result it forces us to change XEPs using this API to async in the
  relevant methods.
  As a rule of thumb, thin wrappers around del/set are generally preserved and return a
  future to guarantee that the task is done, while getters (which would require awaiting
  anyway when returning a future) are now pure coroutines. This inconsistency is a
  tradeoff to prevent wider changes across slixmpp internals and programs using it.
  - XEP-0012, Last Activity:
  - `begin_idle`, `end_idle`, `start_uptime`, `set_last_activity`,
    `del_last_activity` now return futures.
  - XEP-0027: GPG
  - `get_keyids` and `get_keyid` are now coroutines.
  - `set_keyid` and `del_keyid` now return a Future.
  - XEP-0030: Disco
  - `supports`, `has_identity`, `get_info`, `get_items` are now coroutines
  - `set_info``set_items`, `del_items`, `add_item`, `add_identity`,
    `del_identity`, `set_identities`, `del_identities`, `add_feature`,
    `del_feature`, `set_feature`, `set_features`, `del_features`
    now return a Future
  - XEP-0054: Vcard-Temp
  - `get_vcard`, `publish_vcard` are now coroutines.
  - XEP-0095: Stream Initiation
  - `accept` and `decline` are now coroutines.
  - XEP-0115: Entity Capabilities
  - `get_verstring`, `get_caps` are now coroutines.
  - `assign_verstring`, `cache_caps` now return a Future.
  - XEP-0128: Extended disco
  - `set_extended_info`, `add_extended_info` and `del_extended_info` return Futures.
  - XEP-0231: BoB
  - `get_bob` and `set_bob` are now coroutines.
  - `del_bob` returns a Future.
  - XEP-0319: Idle
  - `idle` and `active` are now coroutines.
  XMLStream.process() is now deprecated, and will be removed in the next version.
  This shorthand makes things more confusing for new users, and complicates
  integration with other asyncio libraries.
  - If defusedxml is available, it will be used, to mitigate XML parser vulns
  - `XMLStream.ca_certs` should be a list of paths to the CA certificates
  Nicoco (Nicolas Cedilnik) contributed an implementation of XEP-0356
  (privileged entities), and XEP-100 (gateway interaction).
  The Form element (`{jabber:x:data}x`) can now be accessed properly if their are
  several available in a parent element, through a 'forms' multi attribute.
  - Add an async join method (returns once the rooms is properly joined, or
    raises on error).
  - Deprecate the old join_muc() API
  Nicoco added the possibility to register with components to the existing
  XEP-0077 implementation.
  - MAM preferences have been split into an XEP-0441 plugin.
  - Tests have been added
  - An `iterate()` method has been added, which should be easier to use.
  - XEP-0369: add events for participant and channels
  - XEP-0405: Add a method to retrieve annotated roster items
  - Add a simple MIX bot
  - Make `StanzaBase.get_plugin` a public API, so that slixmpp users can check
    for the existence of a substanza without risking to create it.
  - Change the sphinx theme to [Furo](https://github.com/pradyunsg/furo) which
    has a dark mode, and looks good. See
    [slixmpp.readthedocs.io](https://slixmpp.readthedocs.io).
  - Improve the toctree to be more logical
  - Update obsolete documentation and tutorials (and add some)
  - Update the event index
  - Add the proper XEP title instead of the number to the index, for easier
    discovery and search.
  More integration and stanza/stream tests have been added, which gives us
  more confidence on the overall stability.
  The HTTPUpload example has been updated to include an oob reference, because
  many people were reusing the code as-is and wondering why clients were not
  displaying their images inline.
  A lot of work in this release has been to incrementally type the internals of
  slixmpp as well as the public interfaces, to make it easier to validate changes
  and integrate seemlessy with the various IDEs and typecheckers. It is still
  very much a work in progress, in part due to the dynamicity of the API, but
  it should help catch some errors.
  The library now ships with a py.typed file to indicate that it is shipping
  type annotations.
* Mon Oct 25 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.7.1:
  * No changelog available.
* Wed Jul 29 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.5.2
  * Add ids to presences and messages by default
  * Fix various issues in connection/disconnection
  * Code improvements (typing, deprecation warnings)
  * Fix or improvements for some XEPS
  * New XEPs
  * Groundwork for the OMEMO (XEP-0384) plugin, which has been put
    in a separate repository due to licensing issues.
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Tue Feb  5 2019 mvetter@suse.com
- Update to 1.4.2:
  * Do not do channel binding without TLS
  * Add default timeout of 120s for IQs (prevent slowdowns)
  * Fix CVE-2019-1000021 (bsc#1124322)
  * Do not query vcard avatars unconditionnally
  * Fix GSSAPI (Jelmer Vernooĳ)
* Fri Jan 11 2019 mvetter@suse.com
- Change source URL from GH to https://lab.louiz.org as requested
* Fri Jan 11 2019 mvetter@suse.com
- Update 1.4.1:
  * jid: Make property aliases proper aliases.
  * stanzabase: Remove python2 legacy.
  * fixing uncaught async exceptions due to missing await
  * XEP-0363: Add a domain argument to discover an upload service
  * XEP-0363: Also check for disco#info’s feature
  * XEP-0030: Don’t call the timeout_callback on each domain
  * Decode bytes in GSSAPI handling, as expected by the kerberos module API
- Update source URL
- Add requires python3-aiohttp: was needed for XEP-0363 since 1.4.0
* Tue Aug 14 2018 sor.alexei@meowr.ru
- Update to version 1.4.0:
  * No changelog available.
- Use python-rpm-macros.
* Fri Jul 20 2018 mcepl@suse.com
- Use python3 -munittest discover -v -s tests instead of run_tests.py
* Thu Jul 19 2018 mcepl@suse.com
- Clean SPEC file
* Sun Feb 11 2018 jengelh@inai.de
- Trim future goals from description, say what it does now.
* Sat Jan 20 2018 sor.alexei@meowr.ru
- Update to version 1.3.0:
  * Implement XEP-0300: Use of Cryptographic Hash Functions in XMPP.
  * Return a Future on clientxmpp.get_roster().
  * Fix custom stanza examples.
  * Fix the HTTP over XMPP and GTalk examples.
  * xmlstream: Warn when the parser is None when data is received.
  * Add an XMPP classifier to setup.py.
  * sasl: Merge two bytes instead of concatenating them at runtime.
  * Fix the port being set to 0 when connecting via hostname.
  * Pass SSL context to plain TLS connections.
  * xmlstream: Remove pygments dumping.
  * XEP-0319: Use the correct timezone.
  * Update RSM for asyncio.
  * Update the MAM plugin for asyncio and the new namespace.
    And add an example.
  * XEP-0054: Fix parsing the BINVAL element.
  * Record the current connection attempt in a future and allow
    cancellation.
  * Add a Markup plugin.
- Add the missing requirement of GnuPG.
- Enable tests.
* Sat Feb 11 2017 sor.alexei@meowr.ru
- Update to version 1.2.4:
  * Test more things before trying to build our stringprep module.
  * XMLStream: Break a long line to make it more readable.
  * Check for XML parsing errors and disconnect in that case.
  * Add missing asyncio.coroutine decorators.
  * Fix a partially-merged Google plugin from the commit acc52fd.
  * Fix an issue with carbons (CVE-2017-5589, bsc#1024690).
* Sat Dec 10 2016 sor.alexei@meowr.ru
- Initial package.
